@@ -181,4 +181,46 @@ class MesPtb(object):
             self.__num_mes_ptb = value
         except KeyError:
             self.__num_mes_ptb = 0
-            self.__txt_mes_ptb = 'MES INEXISTENTE'
\ No newline at end of file
+            self.__txt_mes_ptb = 'MES INEXISTENTE'
+
+def error_stack(context, error, message):
+    """
+    Imprime mensagem de erro criada pelo usuário
+    Args:
+        context: contexto onde o erro foi gerado
+        error: nome do erro
+        message: mensagem explicativa do erro
+
+    Returns: apenas imprime o tipo de erro, a mensagem explicativa e a lista de chamadas
+
+    """
+    context = inspect.getframeinfo(inspect.currentframe(), context=1), inspect.getouterframes(inspect.currentframe(),context=1)
+    error = "Erro: " + error
+    print(Color.dark_red_background + Color.bold + Color.white + error + " " * (60 - len(error)) + Color.end)
+    print(message)
+    print('Lista de chamadas:')
+    last = False
+    for id1, item1 in enumerate(context[1]):
+        if last:
+            break
+        item2 = item1[0]
+        filename, lineno, function, code_context, code = inspect.getframeinfo(item2)
+        if function == "<module>":
+            last = True
+        if function not in ('get_context', '__init__', 'error_stack'):
+            function = function.replace("<module>", "__main__")
+            print("file: {}, line: {}, function: {}".format(filename, lineno, function))
+
+class RaiseError(Exception):
+    """
+    Levanta um erro definido pelo usuário
+    """
+
+    def __init__(self, RaisedError, message):
+        """
+
+        Args:
+            RaisedError: Nome do erro
+            message: mensagem explicativa do erro
+        """
+        error_stack(RaisedError, message)
\ No newline at end of file
